@@ -6,5 +6,10 @@ use Moo;
 use TheParameterizedRole;
 
 TheParameterizedRole->apply(
-    [ { attribute => 'foo' }, { attribute => 'bar' } ] );
+    [
+        { attribute => 'foo', method => 'xxx' },
+        { attribute => 'bar', method => 'yyy' }
+    ]
+);
+
 1;
